from django.db import models
from typing import Type


# Create your models here.

class UserTypeModel(models.Model):
    id = models.AutoField(primary_key=True)
    staffTypeName = models.CharField(max_length=200, null=True, blank=True)
    hideStatus = models.IntegerField(default=0)
    createdAt = models.DateTimeField(auto_now_add=True)
    updatedAt = models.DateTimeField(auto_now=True)


class UserModel(models.Model):
    id = models.AutoField(primary_key=True)
    userName = models.CharField(max_length=200, null=True, blank=True)
    userPhone = models.CharField(max_length=200, null=True, blank=True)
    userOTP = models.CharField(max_length=200, null=True, blank=True)
    otpValidate = models.CharField(max_length=200, null=True, blank=True)
    userTypeId = models.ForeignKey(UserTypeModel, on_delete=models.CASCADE)
    hideStatus = models.IntegerField(default=0)
    createdAt = models.DateTimeField(auto_now_add=True)
    updatedAt = models.DateTimeField(auto_now=True)


class UserAddressModel(models.Model):
    id = models.AutoField(primary_key=True)
    userId = models.ForeignKey(UserModel, on_delete=models.CASCADE)
    restaurantAddress = models.CharField(max_length=200, null=True, blank=True)
    restaurantCity = models.CharField(max_length=200, null=True, blank=True)
    restaurantState = models.CharField(max_length=200, null=True, blank=True)
    restaurantCountry = models.CharField(max_length=200, null=True, blank=True)
    restaurantPincode = models.CharField(max_length=200, null=True, blank=True)
    hideStatus = models.IntegerField(default=0)
    createdAt = models.DateTimeField(auto_now_add=True)
    updatedAt = models.DateTimeField(auto_now=True)


class RestaurantModel(models.Model):
    id = models.AutoField(primary_key=True)
    restaurantCode = models.CharField(max_length=200, null=True, blank=True)
    restaurantName = models.CharField(max_length=200, null=True, blank=True)
    restaurantPhone = models.CharField(max_length=200, null=True, blank=True)
    restaurantContactPerson = models.CharField(max_length=200, null=True, blank=True)
    restaurantContactPhone = models.CharField(max_length=200, null=True, blank=True)
    restaurantImage = models.ImageField(upload_to='restaurantImage/', null=True, blank=True)
    restaurantAddress = models.CharField(max_length=2000, null=True, blank=True)
    hideStatus = models.IntegerField(default=0)
    createdAt = models.DateTimeField(auto_now_add=True)
    updatedAt = models.DateTimeField(auto_now=True)


class OrderModel(models.Model):
    id = models.AutoField(primary_key=True)
    orderId = models.CharField(max_length=200, null=True, blank=True)
    userId = models.ForeignKey(UserModel, on_delete=models.CASCADE)
    restaurantId = models.ForeignKey(RestaurantModel, on_delete=models.CASCADE)
    subTotalAmount = models.CharField(max_length=200, null=True, blank=True)
    deliveryCharge = models.CharField(max_length=200, null=True, blank=True)
    totalAmount = models.CharField(max_length=200, null=True, blank=True)
    paymentStatus = models.CharField(max_length=200, null=True, blank=True)
    txnId = models.CharField(max_length=200, null=True, blank=True)
    paymentId = models.CharField(max_length=200, null=True, blank=True)
    orderNotes = models.CharField(max_length=200, null=True, blank=True)
    hideStatus = models.IntegerField(default=0)
    createdAt = models.DateTimeField(auto_now_add=True)
    updatedAt = models.DateTimeField(auto_now=True)


class CartModel(models.Model):
    id = models.AutoField(primary_key=True)
    orderId = models.ForeignKey(OrderModel, on_delete=models.CASCADE, null=True, blank=True)
    userId = models.ForeignKey(UserModel, on_delete=models.CASCADE, null=True, blank=True)
    restaurantId = models.ForeignKey(RestaurantModel, on_delete=models.CASCADE, null=True, blank=True)
    categoryId = models.CharField(max_length=200, null=True, blank=True)
    foodId = models.CharField(max_length=200, null=True, blank=True)
    foodName = models.CharField(max_length=200, null=True, blank=True)
    amount = models.CharField(max_length=200, null=True, blank=True)
    qty = models.CharField(max_length=200, null=True, blank=True)
    totalAmount = models.CharField(max_length=200, null=True, blank=True)
    offlineCartId = models.CharField(max_length=200, null=True, blank=True)
    hideStatus = models.IntegerField(default=0)
    createdAt = models.DateTimeField(auto_now_add=True)
    updatedAt = models.DateTimeField(auto_now=True)
